import { useQuery, useQueryClient } from "@tanstack/react-query";
import { useEffect, useState } from "react";
import { DropdownFilter } from "../components/dropdown-filter";
import { VenueGrid } from "../components/venue-grid";
import { API } from "../lib/api";
import { Environment } from "../lib/environment";
import { TCategory, TTag, TVenue, TVenueFilters } from "../lib/types";

export function Index() {
    const [filteredTags, setFilteredTags] = useState<TTag[]>([]);
    const [filteredCategories, setFilteredCategories] = useState<TCategory[]>([]);

    const api = new API(Environment.BaseAPIUrl);

    const queryClient = useQueryClient();

    const { data: venueData } = useQuery<TVenue[], Error>(["venues", filteredCategories], () => api.getVenues({categories: filteredCategories, tags: filteredTags}));

    const { data: categoryData } = useQuery<TCategory[], Error>(["categories"], api.getCategories);

    const { data: tagData } = useQuery<TTag[], Error>(["tags"], api.getTags);

    // useEffect(() => {
    //     console.log("useeffect called!");
    //     queryClient.invalidateQueries(["venues"]);
    // }, [filteredCategories]);

    return(
        <>
            <h1>Leeds Beer Quest</h1>
            <div style={{ display: "flex", justifyContent: "space-around" }}>
                <DropdownFilter filters={tagData ?? []} setSelectedFilters={setFilteredTags} prefillText={"Tags"} />
                <DropdownFilter filters={categoryData ?? []} setSelectedFilters={setFilteredCategories} prefillText={"Categories"} />
            </div>
            <VenueGrid venueData={venueData ?? []} />
        </>
    );
};